( cd opt/kde/lib ; rm -rf libamaroklib.so.1 )
( cd opt/kde/lib ; ln -sf libamaroklib.so.1.0.0 libamaroklib.so.1 )
( cd opt/kde/lib ; rm -rf libamaroklib.so )
( cd opt/kde/lib ; ln -sf libamaroklib.so.1 libamaroklib.so )
( cd opt/kde/lib ; rm -rf libamarokpud.so.1 )
( cd opt/kde/lib ; ln -sf libamarokpud.so.1.0.0 libamarokpud.so.1 )
( cd opt/kde/lib ; rm -rf libamarokpud.so )
( cd opt/kde/lib ; ln -sf libamarokpud.so.1 libamarokpud.so )
( cd opt/kde/lib ; rm -rf libamarokocsclient.so.4 )
( cd opt/kde/lib ; ln -sf libamarokocsclient.so.4.3.0 libamarokocsclient.so.4 )
( cd opt/kde/lib ; rm -rf libamarokocsclient.so )
( cd opt/kde/lib ; ln -sf libamarokocsclient.so.4 libamarokocsclient.so )
